@@ -1,16 +1,19 @@
 from typing import List
 
-from python_on_whales.utils import DockerCamelModel
+from python_on_whales.utils import DockerCamelModel, all_fields_optional
 
 
+@all_fields_optional
 class PluginMount(DockerCamelModel):
     pass
 
 
+@all_fields_optional
 class PluginDevice(DockerCamelModel):
     pass
 
 
+@all_fields_optional
 class PluginSettings(DockerCamelModel):
     mounts: List[PluginMount]
     env: List[str]
@@ -18,10 +21,12 @@ class PluginSettings(DockerCamelModel):
     devices: List[PluginDevice]
 
 
+@all_fields_optional
 class Interface(DockerCamelModel):
     pass
 
 
+@all_fields_optional
 class PluginConfig(DockerCamelModel):
     docker_version: str
     description: str
@@ -32,6 +37,7 @@ class PluginConfig(DockerCamelModel):
     # TODO: add missing attributes
 
 
+@all_fields_optional
 class PluginInspectResult(DockerCamelModel):
     id: str
     name: str
